<div align="center">
    <img src="https://i.imgur.com/siPt6F9.gif" width="5000" alt="Demo" />
    <h1>Matrix Rain</h1>
    <p>A matrix rain effect written in Python.</p>
</div>

# Installation

```
pip install matrix-rain
```

## Usage

```
matrix_rain [OPTIONS]
```

Options:

-   `--speed`, `-s` - Percentage of normal rain speed. Default: 100
-   `--glitches`, `-g` - Percentage of normal glitch amount. Default: 100
-   `--frequency`, `-f` - Percentage of normal drop frequency. Default: 100
